function [t, y] = solve_implradiokette(tEnd, y0, h, l1, l2)
  // Integration der DGL der Radiokette
  // mit dem impliziten Eulerverfahren.
  //   Argumente
  //       Endzeit tEnd
  //       Startwerte y(0) = y0 (2d-Vektor!)
  //       Schrittweite h
  //       l1, l2: Parameter der Radioketten-DGL
  //   Ergebnis
  //     Spaltenvektor t mit Zeitwerten
  //     Matrix y mit Spaltenvektoren y(t,i) mit Naeherungsloesung yi(t)
  //         der i-ten Komponente
  N = ceil(tEnd/h) + 1; // Zahl der Zeitpunkte
  y = zeros(N,2);       // Vektoren fuer die Loesung
  t = zeros(N,1);
  y(1,:) = y0;
  t(1) = 0;
  for I = 2:N
    y(I,1) = y(I-1,1)/(1 + h*l1);
    y(I,2) = (y(I-1,2) + h*l1*y(I-1,1)/(1+h*l1))/(1+h*l2);
    t(I) = t(I-1) + h;
  end
endfunction

